@@ -10,24 +10,24 @@ pub struct ContainerBuilder {
 impl ContainerBuilder {
     pub fn bind_interface<TInterface,TType>() -> InterfaceBuilder<TInterface,TType>
     where 
-        TInterface: 'static + ?Sized,
-        TType: Injection + Unsize<TInterface> + 'static
+        TInterface: ?Sized + Send + Sync + 'static,
+        TType: Injection + Unsize<TInterface> + Send + Sync + 'static
     {
         InterfaceBuilder{phantom_interface: PhantomData, phantom_type: PhantomData, constructor: None, instance: None}
     }
 
-    pub fn bind_type<TType>() -> TypeBuilder<TType> where TType: Injection + 'static  {
+    pub fn bind_type<TType>() -> TypeBuilder<TType> where TType: Injection + Send + Sync + 'static  {
         TypeBuilder{phantom: PhantomData, constructor: None, instance: None}
     }
 
-    pub fn bind_unconfigured_type<TType>() -> UnconfiguredTypeBuilder<TType> where TType: 'static {
+    pub fn bind_unconfigured_type<TType>() -> UnconfiguredTypeBuilder<TType> where TType: Send + Sync + 'static {
         UnconfiguredTypeBuilder{phantom: PhantomData}
     }
 
     pub fn bind_unconfigured_interface<TInterface, TType>() -> UnconfiguredInterfaceBuilder<TInterface, TType>
         where 
-        TInterface: 'static + ?Sized,
-        TType: Unsize<TInterface> + 'static
+        TInterface: ?Sized + Send + Sync + 'static,
+        TType: Unsize<TInterface> + Send + Sync + 'static
     {
         UnconfiguredInterfaceBuilder{phantom_interface: PhantomData, phantom_type: PhantomData}
     }
