@@ -1,4 +1,4 @@
-#[derive(Debug)]
+#[derive(Debug, PartialEq)]
 pub enum DiError {
     CustomInjectTimeError(String),
     ContainerNotFound{type_name: String},
