@@ -1,3 +1,5 @@
+use tokio::runtime::Runtime;
+
 struct InnerStruct {
     #[allow(dead_code)]
     pub text: String,
@@ -26,14 +28,18 @@ impl crate::Injection for OuterStruct {
 
 #[test]
 fn one_type_inject() {
-    let containers = vec![
-        crate::builders::ContainerBuilder::bind_type::<InnerStruct>().build(),
-        crate::builders::ContainerBuilder::bind_type::<OuterStruct>().build(),
-    ];
+    let rt  = Runtime::new().unwrap();  
 
-    let injector = crate::Injector::new(containers);
+    rt.block_on(async {
+        let containers = vec![
+            crate::builders::ContainerBuilder::bind_type::<InnerStruct>().build(),
+            crate::builders::ContainerBuilder::bind_type::<OuterStruct>().build(),
+        ];
 
-    let obj = injector.write().unwrap().get_new_instance::<OuterStruct>().unwrap();
+        let injector = crate::Injector::new(containers).await;
 
-    assert_eq!(obj.inner.text, "test".to_string());
+        let obj = injector.write().await.get_new_instance::<OuterStruct>().unwrap();
+
+        assert_eq!(obj.inner.text, "test".to_string());
+    });
 }
\ No newline at end of file
