@@ -53,7 +53,6 @@ fn unconfigured_type_with_castom_instance_singletone_instance() {
 }
 
 #[test]
-#[should_panic]
 fn unconfigured_type_with_castom_instance_new_instance_panic() {
     let rt  = Runtime::new().unwrap();  
 
@@ -65,7 +64,7 @@ fn unconfigured_type_with_castom_instance_new_instance_panic() {
 
         let injector = crate::Injector::new(containers).await;
 
-        let obj = injector.write().await.get_new_instance::<StructWithCustomInstance>().unwrap();
-        assert_eq!(obj.string, "".to_string());
+        let obj = injector.write().await.get_new_instance::<StructWithCustomInstance>();
+        assert_eq!(obj.err(), Some(crate::DiError::ConstructorNotDefined{type_name: std::any::type_name::<StructWithCustomInstance>().to_string()}));
     });
 }
\ No newline at end of file
